@@ -15,8 +15,7 @@ var searchData=
   ['pagenumber',['PageNumber',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1PageNumber.html',1,'com::sun::star::text::textfield']]],
   ['pageprintsettings',['PagePrintSettings',['../servicecom_1_1sun_1_1star_1_1text_1_1PagePrintSettings.html',1,'com::sun::star::text']]],
   ['pageproperties',['PageProperties',['../servicecom_1_1sun_1_1star_1_1style_1_1PageProperties.html',1,'com::sun::star::style']]],
-  ['pageshape',['PageShape',['../servicecom_1_1sun_1_1star_1_1drawing_1_1PageShape.html',1,'com::sun::star::drawing']]],
-  ['pageshape',['PageShape',['../servicecom_1_1sun_1_1star_1_1presentation_1_1PageShape.html',1,'com::sun::star::presentation']]],
+  ['pageshape',['PageShape',['../servicecom_1_1sun_1_1star_1_1drawing_1_1PageShape.html',1,'PageShape'],['../servicecom_1_1sun_1_1star_1_1presentation_1_1PageShape.html',1,'PageShape']]],
   ['pagestyle',['PageStyle',['../servicecom_1_1sun_1_1star_1_1style_1_1PageStyle.html',1,'com::sun::star::style']]],
   ['paintevent',['PaintEvent',['../structcom_1_1sun_1_1star_1_1awt_1_1PaintEvent.html',1,'com::sun::star::awt']]],
   ['pair_3c_20t_2c_20u_20_3e',['Pair&lt; T, U &gt;',['../structcom_1_1sun_1_1star_1_1beans_1_1Pair_3_01T_00_01U_01_4.html',1,'com::sun::star::beans']]],
@@ -41,8 +40,7 @@ var searchData=
   ['passwordrequest',['PasswordRequest',['../exceptioncom_1_1sun_1_1star_1_1task_1_1PasswordRequest.html',1,'com::sun::star::task']]],
   ['pathsettings',['PathSettings',['../servicecom_1_1sun_1_1star_1_1util_1_1PathSettings.html',1,'com::sun::star::util']]],
   ['pathsubstitution',['PathSubstitution',['../servicecom_1_1sun_1_1star_1_1util_1_1PathSubstitution.html',1,'com::sun::star::util']]],
-  ['patternfield',['PatternField',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1PatternField.html',1,'com::sun::star::form::component']]],
-  ['patternfield',['PatternField',['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1PatternField.html',1,'com::sun::star::form::control']]],
+  ['patternfield',['PatternField',['../servicecom_1_1sun_1_1star_1_1form_1_1component_1_1PatternField.html',1,'PatternField'],['../servicecom_1_1sun_1_1star_1_1form_1_1control_1_1PatternField.html',1,'PatternField']]],
   ['pdfdialog',['PDFDialog',['../servicecom_1_1sun_1_1star_1_1document_1_1PDFDialog.html',1,'com::sun::star::document']]],
   ['pdfexportexception',['PDFExportException',['../exceptioncom_1_1sun_1_1star_1_1task_1_1PDFExportException.html',1,'com::sun::star::task']]],
   ['persistencefailureexception',['PersistenceFailureException',['../exceptioncom_1_1sun_1_1star_1_1auth_1_1PersistenceFailureException.html',1,'com::sun::star::auth']]],
@@ -74,9 +72,7 @@ var searchData=
   ['postcommandargument2',['PostCommandArgument2',['../structcom_1_1sun_1_1star_1_1ucb_1_1PostCommandArgument2.html',1,'com::sun::star::ucb']]],
   ['potentialregressioncurve',['PotentialRegressionCurve',['../servicecom_1_1sun_1_1star_1_1chart2_1_1PotentialRegressionCurve.html',1,'com::sun::star::chart2']]],
   ['powerscaling',['PowerScaling',['../servicecom_1_1sun_1_1star_1_1chart2_1_1PowerScaling.html',1,'com::sun::star::chart2']]],
-  ['preparedstatement',['PreparedStatement',['../servicecom_1_1sun_1_1star_1_1sdb_1_1PreparedStatement.html',1,'com::sun::star::sdb']]],
-  ['preparedstatement',['PreparedStatement',['../servicecom_1_1sun_1_1star_1_1sdbc_1_1PreparedStatement.html',1,'com::sun::star::sdbc']]],
-  ['preparedstatement',['PreparedStatement',['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1PreparedStatement.html',1,'com::sun::star::sdbcx']]],
+  ['preparedstatement',['PreparedStatement',['../servicecom_1_1sun_1_1star_1_1sdb_1_1PreparedStatement.html',1,'PreparedStatement'],['../servicecom_1_1sun_1_1star_1_1sdbc_1_1PreparedStatement.html',1,'PreparedStatement'],['../servicecom_1_1sun_1_1star_1_1sdbcx_1_1PreparedStatement.html',1,'PreparedStatement']]],
   ['presentation',['Presentation',['../servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation.html',1,'com::sun::star::presentation']]],
   ['presentation2',['Presentation2',['../servicecom_1_1sun_1_1star_1_1presentation_1_1Presentation2.html',1,'com::sun::star::presentation']]],
   ['presentationdocument',['PresentationDocument',['../servicecom_1_1sun_1_1star_1_1presentation_1_1PresentationDocument.html',1,'com::sun::star::presentation']]],
@@ -92,8 +88,7 @@ var searchData=
   ['printerserver',['PrinterServer',['../servicecom_1_1sun_1_1star_1_1awt_1_1PrinterServer.html',1,'com::sun::star::awt']]],
   ['printjobevent',['PrintJobEvent',['../structcom_1_1sun_1_1star_1_1view_1_1PrintJobEvent.html',1,'com::sun::star::view']]],
   ['printoptions',['PrintOptions',['../servicecom_1_1sun_1_1star_1_1view_1_1PrintOptions.html',1,'com::sun::star::view']]],
-  ['printsettings',['PrintSettings',['../servicecom_1_1sun_1_1star_1_1text_1_1PrintSettings.html',1,'com::sun::star::text']]],
-  ['printsettings',['PrintSettings',['../servicecom_1_1sun_1_1star_1_1view_1_1PrintSettings.html',1,'com::sun::star::view']]],
+  ['printsettings',['PrintSettings',['../servicecom_1_1sun_1_1star_1_1text_1_1PrintSettings.html',1,'PrintSettings'],['../servicecom_1_1sun_1_1star_1_1view_1_1PrintSettings.html',1,'PrintSettings']]],
   ['proofreader',['Proofreader',['../servicecom_1_1sun_1_1star_1_1linguistic2_1_1Proofreader.html',1,'com::sun::star::linguistic2']]],
   ['proofreadingiterator',['ProofreadingIterator',['../servicecom_1_1sun_1_1star_1_1linguistic2_1_1ProofreadingIterator.html',1,'com::sun::star::linguistic2']]],
   ['proofreadingresult',['ProofreadingResult',['../structcom_1_1sun_1_1star_1_1linguistic2_1_1ProofreadingResult.html',1,'com::sun::star::linguistic2']]],
